@@ -1,6 +1,6 @@
 #define DEBUG 1
-#define VERSION "3.12.1"
-#define ADATE   "06 January 2006"
+#define VERSION "3.12.3"
+#define ADATE   "26 April 2006"
 
 #define APCUPSD_RELEASE VERSION
 
